@@ -4,22 +4,25 @@ test_that("ESPN - Get NBA play by play only", {
 
 
   cols <- c(
-    "shooting_play",
+    "id",
     "sequence_number",
+    "text",
+    "away_score",
     "home_score",
     "scoring_play",
-    "away_score",
-    "id",
-    "text",
     "score_value",
-    "period_display_value",
-    "period_number",
-    "coordinate_x",
-    "coordinate_y",
-    "clock_display_value",
-    "team_id",
+    "wallclock",
+    "shooting_play",
     "type_id",
     "type_text",
+    "period_number",
+    "period_display_value",
+    "clock_display_value",
+    "team_id",
+    "coordinate_x_raw",
+    "coordinate_y_raw",
+    "coordinate_x",
+    "coordinate_y",
     "play_id",
     "athlete_id_1",
     "athlete_id_2",
@@ -51,9 +54,10 @@ test_that("ESPN - Get NBA play by play only", {
     "game_id",
     "season",
     "season_type",
-    "game_date"
+    "game_date",
+    "game_date_time"
   )
-  expect_equal(colnames(x), cols)
-  expect_s3_class(x, 'data.frame')
+  expect_equal(sort(colnames(x)), sort(cols))
+  expect_s3_class(x, "data.frame")
 
 })
