@@ -6,22 +6,25 @@ test_that("ESPN - Get NBA play by play all", {
   x3 <- x[[3]]
 
   cols_x1 <- c(
-    "shooting_play",
+    "id",
     "sequence_number",
+    "text",
+    "away_score",
     "home_score",
     "scoring_play",
-    "away_score",
-    "id",
-    "text",
     "score_value",
-    "period_display_value",
-    "period_number",
-    "coordinate_x",
-    "coordinate_y",
-    "clock_display_value",
-    "team_id",
+    "wallclock",
+    "shooting_play",
     "type_id",
     "type_text",
+    "period_number",
+    "period_display_value",
+    "clock_display_value",
+    "team_id",
+    "coordinate_x_raw",
+    "coordinate_y_raw",
+    "coordinate_x",
+    "coordinate_y",
     "play_id",
     "athlete_id_1",
     "athlete_id_2",
@@ -53,94 +56,135 @@ test_that("ESPN - Get NBA play by play all", {
     "game_id",
     "season",
     "season_type",
-    "game_date"
+    "game_date",
+    "game_date_time"
   )
   cols_x2 <- c(
     "game_id",
     "season",
     "season_type",
     "game_date",
-    "team_short_display_name",
-    "team_uid",
-    "team_alternate_color",
-    "team_color",
-    "team_display_name",
-    "team_name",
-    "team_logo",
-    "team_location",
+    "game_date_time",
     "team_id",
-    "team_abbreviation",
+    "team_uid",
     "team_slug",
-    "field_goals_made_field_goals_attempted",
+    "team_location",
+    "team_name",
+    "team_abbreviation",
+    "team_display_name",
+    "team_short_display_name",
+    "team_color",
+    "team_alternate_color",
+    "team_logo",
+    "team_home_away",
+    "team_score",
+    "team_winner",
+    "assists",
+    "blocks",
+    "defensive_rebounds",
+    "fast_break_points",
     "field_goal_pct",
-    "three_point_field_goals_made_three_point_field_goals_attempted",
-    "three_point_field_goal_pct",
-    "free_throws_made_free_throws_attempted",
+    "field_goals_made",
+    "field_goals_attempted",
+    "flagrant_fouls",
+    "fouls",
     "free_throw_pct",
+    "free_throws_made",
+    "free_throws_attempted",
+    "largest_lead",
+    "offensive_rebounds",
+    "points_in_paint",
+    "steals",
+    "team_turnovers",
+    "technical_fouls",
+    "three_point_field_goal_pct",
+    "three_point_field_goals_made",
+    "three_point_field_goals_attempted",
     "total_rebounds",
+    "total_technical_fouls",
+    "total_turnovers",
+    "turnover_points",
+    "turnovers",
+    "opponent_team_id",
+    "opponent_team_uid",
+    "opponent_team_slug",
+    "opponent_team_location",
+    "opponent_team_name",
+    "opponent_team_abbreviation",
+    "opponent_team_display_name",
+    "opponent_team_short_display_name",
+    "opponent_team_color",
+    "opponent_team_alternate_color",
+    "opponent_team_logo",
+    "opponent_team_score"
+  )
+  cols_x3 <- c(
+    "game_id",
+    "season",
+    "season_type",
+    "game_date",
+    "game_date_time",
+    "athlete_id",
+    "athlete_display_name",
+    "team_id",
+    "team_name",
+    "team_location",
+    "team_short_display_name",
+    "minutes",
+    "field_goals_made",
+    "field_goals_attempted",
+    "three_point_field_goals_made",
+    "three_point_field_goals_attempted",
+    "free_throws_made",
+    "free_throws_attempted",
     "offensive_rebounds",
     "defensive_rebounds",
+    "rebounds",
     "assists",
     "steals",
     "blocks",
     "turnovers",
-    "team_turnovers",
-    "total_turnovers",
-    "technical_fouls",
-    "total_technical_fouls",
-    "flagrant_fouls",
-    "turnover_points",
-    "fast_break_points",
-    "points_in_paint",
     "fouls",
-    "largest_lead",
-    "home_away",
-    "opponent_id",
-    "opponent_name",
-    "opponent_mascot",
-    "opponent_abbrev"
-  )
-  cols_x3 <- c(
-    "athlete_display_name",
-    "team_short_display_name",
-    "min",
-    "fg",
-    "fg3",
-    "ft",
-    "oreb",
-    "dreb",
-    "reb",
-    "ast",
-    "stl",
-    "blk",
-    "to",
-    "pf",
-    "+/-",
-    "pts",
+    "plus_minus",
+    "points",
     "starter",
     "ejected",
     "did_not_play",
+    "reason",
     "active",
     "athlete_jersey",
-    "athlete_id",
     "athlete_short_name",
     "athlete_headshot_href",
     "athlete_position_name",
     "athlete_position_abbreviation",
-    "team_name",
+    "team_display_name",
+    "team_uid",
+    "team_slug",
     "team_logo",
-    "team_id",
     "team_abbreviation",
     "team_color",
-    "team_alternate_color"
+    "team_alternate_color",
+    "home_away",
+    "team_winner",
+    "team_score",
+    "opponent_team_id",
+    "opponent_team_name",
+    "opponent_team_location",
+    "opponent_team_display_name",
+    "opponent_team_abbreviation",
+    "opponent_team_logo",
+    "opponent_team_color",
+    "opponent_team_alternate_color",
+    "opponent_team_score"
   )
-  expect_equal(colnames(x1), cols_x1)
-  expect_s3_class(x1, 'data.frame')
 
-  expect_equal(colnames(x2), cols_x2)
-  expect_s3_class(x2, 'data.frame')
+  expect_equal(sort(colnames(x1)), sort(cols_x1))
+  expect_s3_class(x1, "data.frame")
 
-  expect_equal(colnames(x3), cols_x3)
-  expect_s3_class(x3, 'data.frame')
+  expect_equal(sort(colnames(x2)), sort(cols_x2))
+  expect_s3_class(x2, "data.frame")
+
+  expect_equal(sort(colnames(x3)), sort(cols_x3))
+  expect_s3_class(x3, "data.frame")
 
 })
