@@ -1,6 +1,3 @@
-context("ESPN - Get NBA team box score only")
-
-
 
 test_that("ESPN - Get NBA team box score only", {
   skip_on_cran()
@@ -11,47 +8,61 @@ test_that("ESPN - Get NBA team box score only", {
     "season",
     "season_type",
     "game_date",
-    "team_short_display_name",
-    "team_uid",
-    "team_alternate_color",
-    "team_color",
-    "team_display_name",
-    "team_name",
-    "team_logo",
-    "team_location",
+    "game_date_time",
     "team_id",
-    "team_abbreviation",
+    "team_uid",
     "team_slug",
-    "field_goals_made_field_goals_attempted",
-    "field_goal_pct",
-    "three_point_field_goals_made_three_point_field_goals_attempted",
-    "three_point_field_goal_pct",
-    "free_throws_made_free_throws_attempted",
-    "free_throw_pct",
-    "total_rebounds",
-    "offensive_rebounds",
-    "defensive_rebounds",
+    "team_location",
+    "team_name",
+    "team_abbreviation",
+    "team_display_name",
+    "team_short_display_name",
+    "team_color",
+    "team_alternate_color",
+    "team_logo",
+    "team_home_away",
+    "team_score",
+    "team_winner",
     "assists",
-    "steals",
     "blocks",
-    "turnovers",
-    "team_turnovers",
-    "total_turnovers",
-    "technical_fouls",
-    "total_technical_fouls",
-    "flagrant_fouls",
-    "turnover_points",
+    "defensive_rebounds",
     "fast_break_points",
-    "points_in_paint",
+    "field_goal_pct",
+    "field_goals_made",
+    "field_goals_attempted",
+    "flagrant_fouls",
     "fouls",
+    "free_throw_pct",
+    "free_throws_made",
+    "free_throws_attempted",
     "largest_lead",
-    "home_away",
-    "opponent_id",
-    "opponent_name",
-    "opponent_mascot",
-    "opponent_abbrev"
+    "offensive_rebounds",
+    "points_in_paint",
+    "steals",
+    "team_turnovers",
+    "technical_fouls",
+    "three_point_field_goal_pct",
+    "three_point_field_goals_made",
+    "three_point_field_goals_attempted",
+    "total_rebounds",
+    "total_technical_fouls",
+    "total_turnovers",
+    "turnover_points",
+    "turnovers",
+    "opponent_team_id",
+    "opponent_team_uid",
+    "opponent_team_slug",
+    "opponent_team_location",
+    "opponent_team_name",
+    "opponent_team_abbreviation",
+    "opponent_team_display_name",
+    "opponent_team_short_display_name",
+    "opponent_team_color",
+    "opponent_team_alternate_color",
+    "opponent_team_logo",
+    "opponent_team_score"
   )
-  expect_equal(colnames(x), cols)
-  expect_s3_class(x, 'data.frame')
+  expect_equal(sort(colnames(x)), sort(cols))
+  expect_s3_class(x, "data.frame")
 
 })
