@@ -1,7 +1,9 @@
 test_that("KP - Get conference history", {
   skip_on_cran()
+  skip_on_ci()
+  skip_kenpom_test()
 
-  x <- kp_confhistory(conf='ACC')
+  x <- kp_confhistory(conf="ACC")
 
 
   cols <- c(
@@ -12,5 +14,8 @@ test_that("KP - Get conference history", {
     "tourney_champ", "best_team")
 
   expect_equal(colnames(x), cols)
-  expect_s3_class(x,'data.frame')
+  expect_s3_class(x,"data.frame")
+
+  Sys.sleep(3)
+
 })
