@@ -1,8 +1,9 @@
 test_that("KP - Get team player stats", {
   skip_on_cran()
   skip_on_ci()
+  skip_kenpom_test()
 
-  x <- kp_team_player_stats(team = 'Florida St.', year = 2020)
+  x <- kp_team_player_stats(team = "Florida St.", year = 2020)
 
   cols <- c(
     "role", "number", "player", "ht", "wt", "yr",
@@ -18,8 +19,9 @@ test_that("KP - Get team player stats", {
     "fg_3_pct_rk", "group_rank", "team", "year", "player_id"
   )
 
-  expect_equal(colnames(x), cols)
-  expect_s3_class(x, 'data.frame')
+  expect_equal(colnames(x[[1]]), cols)
+  expect_s3_class(x[[1]], "data.frame")
 
+  Sys.sleep(3)
 
 })
