@@ -1,8 +1,9 @@
 test_that("KP - Get team players (roster)", {
   skip_on_cran()
   skip_on_ci()
+  skip_kenpom_test()
 
-  x <- kp_team_players(team = 'Florida St.', year= 2020)
+  x <- kp_team_players(team = "Florida St.", year= 2020)
 
 
   cols <- c(
@@ -17,6 +18,8 @@ test_that("KP - Get team players (roster)", {
     "fg_2_pct_rk", "fg_3_pct_rk", "national_rank", "team", "year", "player_id"
   )
   expect_equal(colnames(x), cols)
-  expect_s3_class(x, 'data.frame')
+  expect_s3_class(x, "data.frame")
+
+  Sys.sleep(3)
 
 })
