@@ -2,8 +2,9 @@
 test_that("KP - Get team schedule", {
   skip_on_cran()
   skip_on_ci()
+  skip_kenpom_test()
 
-  x <- kp_team_schedule(team = 'Florida St.', year= 2020)
+  x <- kp_team_schedule(team = "Florida St.", year= 2020)
 
   cols <- c(
     "team_rk", "team", "opponent_rk", "opponent", "result",
@@ -15,5 +16,8 @@ test_that("KP - Get team schedule", {
   )
 
   expect_equal(colnames(x), cols)
-  expect_s3_class(x,'data.frame')
+  expect_s3_class(x,"data.frame")
+
+  Sys.sleep(3)
+
 })
