@@ -1,6 +1,7 @@
 test_that("KP - Get trends", {
   skip_on_cran()
   skip_on_ci()
+  skip_kenpom_test()
 
   x <- kp_trends()
 
@@ -13,5 +14,8 @@ test_that("KP - Get trends", {
 
 
   expect_equal(colnames(x), cols)
-  expect_s3_class(x, 'data.frame')
+  expect_s3_class(x, "data.frame")
+
+  Sys.sleep(3)
+
 })
